﻿Micromalist = LibStub("AceAddon-3.0"):NewAddon("Micromalist", "AceEvent-3.0", "AceHook-3.0", "AceConsole-3.0", "AceTimer-3.0")

local db = nil
local mod = Micromalist

local defaults = {
	profile = {
		IGNOREDUELS = false,
		AUTOREPAIR = 1,
		AUTOSELL = false,
		AUTOREZ = false,
		GOSSIPSKIP = false,
		REPUTATION = true,
		GRYPH = true,
		QUESTLEVEL = true,
		QUESTACCEPT = false,
		CHATNOFADE = false,
		CHATARROWS = false,
		CHATBUTTONS = false,
		CHATEDIT = false,
		CHATCLEAN = false,
		MAPHIDE = false,
		MAPLOC = false,
		MAPSCROLL = false,
		MAPHIDEWORLDMAPBTN = false,
		MAPHIDETRACKINGBTN = false,
		AUTOPLATES = false,
		BLOATTHREAT = false,
		SPREADPLATES = false,
		AUTOLOOT = false,
	}
}

function Micromalist:OnInitialize()
	self.Merchant_Show = false
	self.Gossip_Show = false
	self.abacus = LibStub("LibAbacus-3.0")

	--# Initialize DB
	self.db = LibStub("AceDB-3.0"):New("MicromalistDB", defaults)
	db = self.db.profile

	--# Initialize Chat
	for i = 1, NUM_CHAT_WINDOWS do
		--Allow resizing chatframes to whatever size you wish!
		local cf = _G[format("%s%d", "ChatFrame", i)]
		cf:SetMinResize(0,0)
		cf:SetMaxResize(0,0)

		--Allow the chat frame to move to the end of the screen
		cf:SetClampRectInsets(0,0,0,0)

		--Clamp the toast frame to screen to prevent it cutting out
		BNToastFrame:SetClampedToScreen(true)
	end
	
	--# Slash Commands
	--# /min or /minimlalist: Open Options Panel
	SlashCmdList["Micromalist"] = function() InterfaceOptionsFrame_OpenToCategory("Micromalist") end
	SLASH_Micromalist1 = "/Micromalist"
	SLASH_Micromalist2 = "/mic"

	--# /rl: Reload UI
	SlashCmdList["RELOADUI"] = function() ReloadUI() end
	SLASH_RELOADUI1 = "/rl"

	--# /rg: Restart GFX Subsystem
	SlashCmdList["RESTARTGX"] = function() RestartGx() end
	SLASH_RESTARTGX1 = "/rg"
end

function Micromalist:OnEnable()
	ChatButtonsOff()
	ChatMoveEditBox()
	ChatArrowsOff()
end

function Micromalist:MinSellJunk()
	local bag, slot
	for bag = 0, 4 do
		if GetContainerNumSlots(bag) > 0 then
			for slot = 1, GetContainerNumSlots(bag) do
				local _, _, _, quality = GetContainerItemInfo(bag, slot)
				if (quality == 0 or quality == -1) then
					if (self:ProcessLink(GetContainerItemLink(bag, slot))) then
						UseContainerItem(bag, slot)
					end
				end
			end
		end
	end
end

function Micromalist:ProcessLink(link)
	for color, name in string.gmatch(link, "(|c%x+)|Hitem:.+|h%[(.-)%]|h|r") do
	if color == ITEM_QUALITY_COLORS[0].hex then
		return true
	end
		return false
	end
end

function Micromalist:RESURRECT_REQUEST()
	if not IsShiftKeyDown() then
		if (arg1 == "Chained Spirit") then return end
		if (GetCorpseRecoveryDelay() ~= 0) then return end
		HideUIPanel(StaticPopup1)
		AcceptResurrect()
	end
end

function Micromalist:DUEL_REQUESTED()
	if not IsShiftKeyDown() then
		HideUIPanel(StaticPopup1)
		CancelDuel()
	end
end


function Micromalist:ChatButtonsOff()
	if (not ChatFrameMenuButton:IsVisible()) then return end
	local hideFunc = function(frame) frame:Hide() end

	ChatFrameMenuButton:SetScript("OnShow", hideFunc)
	ChatFrameMenuButton:Hide()
	FriendsMicroButton:SetScript("OnShow", hideFunc)
	FriendsMicroButton:Hide()

	for i = 1, NUM_CHAT_WINDOWS do
		local bf = _G[format("%s%d%s", "ChatFrame", i, "ButtonFrame")]
		bf:SetScript("OnShow", hideFunc)
		bf:Hide()
	end
end

function Micromalist:OnShow()
	this:Hide()
end

function Micromalist:ChatMoveEditBox()
	for i = 1, NUM_CHAT_WINDOWS do
		local eb =  _G[format("%s%d%s", "ChatFrame", i, "EditBox")]
		local cf = _G[format("%s%d", "ChatFrame", i)]
		eb:ClearAllPoints()
		eb:SetPoint("BOTTOMLEFT",  cf, "TOPLEFT",  -5, -5)
		eb:SetPoint("BOTTOMRIGHT", cf, "TOPRIGHT", 0, -5)
	end
end

function Micromalist:ChatArrowsOff()
	for i = 1, NUM_CHAT_WINDOWS do
		--Allow arrow keys editing in the edit box
		local eb =  _G[format("%s%d%s", "ChatFrame", i, "EditBox")]
		eb:SetAltArrowKeyMode(false)
	end
end
